@@ -44,7 +44,7 @@ class Delete(base.DeleteCommand):
   detailed_help = {'EXAMPLES': _EXAMPLES}
 
   @staticmethod
-  def Args(parser: parser_arguments.ArgumentInterceptor):
+  def Args(parser: parser_arguments.ArgumentInterceptor) -> None:
     """Registers flags for the delete command."""
     flags = rollout_flags.RolloutFlags(parser)
     flags.AddRolloutResourceArg()
@@ -74,6 +74,8 @@ class Delete(base.DeleteCommand):
         release_track=base.ReleaseTrack.ALPHA
     )
     completed_operation = operation_client.Wait(util.OperationRef(operation))
-    log.Print('Deleted Fleet rollout [{}].'.format(rollout_ref.SelfLink()))
+    log.status.Print(
+        'Deleted Fleet rollout [{}].'.format(rollout_ref.SelfLink())
+    )
 
     return completed_operation
